pub struct XmtpMlsLocalContext<ApiClient, Db, S> { /* private fields */ }Expand description
The local context a XMTP MLS needs to function:
- Sqlite Database
- Identity for the User
Implementations
Sourceimpl<ApiClient, Db, S> XmtpMlsLocalContext<ApiClient, Db, S>
impl<ApiClient, Db, S> XmtpMlsLocalContext<ApiClient, Db, S>
Sourcepub fn db(&self) -> Db::DbQuery
pub fn db(&self) -> Db::DbQuery
get a reference to the monolithic Database object where higher-level queries are defined
Sourcepub fn mls_provider(&self) -> XmtpOpenMlsProviderRef<'_, S>
pub fn mls_provider(&self) -> XmtpOpenMlsProviderRef<'_, S>
Creates a new MLS Provider
pub fn store(&self) -> &Db
pub fn scw_verifier(&self) -> &Arc<Box<dyn SmartContractSignatureVerifier>> ⓘ
pub fn device_sync_worker_enabled(&self) -> bool
Sourceimpl<ApiClient, Db, S> XmtpMlsLocalContext<ApiClient, Db, S>
impl<ApiClient, Db, S> XmtpMlsLocalContext<ApiClient, Db, S>
pub fn replace_mls_store<S2>( self, mls_store: S2, ) -> XmtpMlsLocalContext<ApiClient, Db, S2>
Sourceimpl<ApiClient, Db, S> XmtpMlsLocalContext<ApiClient, Db, S>
impl<ApiClient, Db, S> XmtpMlsLocalContext<ApiClient, Db, S>
Sourcepub fn installation_public_key(&self) -> InstallationId
pub fn installation_public_key(&self) -> InstallationId
The installation public key is the primary identifier for an installation
Sourcepub fn installation_id(&self) -> InstallationId
pub fn installation_id(&self) -> InstallationId
The installation public key is the primary identifier for an installation
Sourcepub fn inbox_id(&self) -> InboxIdRef<'_>
pub fn inbox_id(&self) -> InboxIdRef<'_>
Get the account address of the blockchain account associated with this client
Sourcepub fn signature_request(&self) -> Option<SignatureRequest>
pub fn signature_request(&self) -> Option<SignatureRequest>
Integrators should always check the signature_request return value of this function before calling register_identity.
If signature_request returns None, then the wallet signature is not required and register_identity can be called with None as an argument.
pub fn sign_with_public_context( &self, text: impl AsRef<str>, ) -> Result<Vec<u8>, IdentityError>
pub fn sync_metrics(&self) -> Option<Arc<WorkerMetrics<SyncMetric>>>
pub fn cancellation_token(&self) -> &CancellationToken
pub fn shutdown_complete(&self) -> bool
pub fn mark_shutdown_complete(&self)