pub fn update_required_capabilities_for_proposals(
extensions: &mut Extensions<GroupContext>,
add: bool,
) -> Result<(), GroupError>Expand description
Update the RequiredCapabilities extension to add or remove
ExtensionType::AppDataDictionary. Per MLS RFC 9420 7.2, unknown
extensions in the group context MUST be listed in the required
capabilities, so this must be called whenever the AppData
dictionary extension is added to or removed from the group context.