is_policy_admin_only

Function is_policy_admin_only 

pub fn is_policy_admin_only(policy: &PolicySet) -> Result<bool, PolicyError>
Checks if a PolicySet is equivalent to the “Admin Only” preconfigured policy.

Depending on if the client is on a newer or older version of libxmtp since the group was created, the number of metadata policies might not match the default Admin Only Policy Set. As long as all metadata policies are admin only, we will match against Admin Only Preconfigured Policy