is_policy_default

Function is_policy_default 

pub fn is_policy_default(policy: &PolicySet) -> Result<bool, PolicyError>
Checks if a PolicySet is equivalent to the “All Members” preconfigured policy.

Depending on if the client is on a newer or older version of libxmtp since the group was created, the number of metadata policies might not match the default All Members Policy Set. As long as all metadata policies are allow, we will match against All Members Preconfigured Policy