pub struct PolicySet {
pub add_member_policy: MembershipPolicies,
pub remove_member_policy: MembershipPolicies,
pub update_metadata_policy: HashMap<String, MetadataPolicies>,
pub add_admin_policy: PermissionsPolicies,
pub remove_admin_policy: PermissionsPolicies,
pub update_permissions_policy: PermissionsPolicies,
}Expand description
Represents a set of policies for a group.
Fields
add_member_policy: MembershipPoliciesThe policy for adding members to the group.
remove_member_policy: MembershipPoliciesThe policy for removing members from the group.
update_metadata_policy: HashMap<String, MetadataPolicies>The policies for updating metadata fields.
add_admin_policy: PermissionsPoliciesThe policy for adding admins to the group.
remove_admin_policy: PermissionsPoliciesThe policy for removing admins from the group.
update_permissions_policy: PermissionsPoliciesThe policy for updating permissions.
Implementations
Sourceimpl PolicySet
impl PolicySet
Sourcepub fn new(
add_member_policy: MembershipPolicies,
remove_member_policy: MembershipPolicies,
update_metadata_policy: HashMap<String, MetadataPolicies>,
add_admin_policy: PermissionsPolicies,
remove_admin_policy: PermissionsPolicies,
update_permissions_policy: PermissionsPolicies,
) -> Self
pub fn new( add_member_policy: MembershipPolicies, remove_member_policy: MembershipPolicies, update_metadata_policy: HashMap<String, MetadataPolicies>, add_admin_policy: PermissionsPolicies, remove_admin_policy: PermissionsPolicies, update_permissions_policy: PermissionsPolicies, ) -> Self
Creates a new PolicySet instance.
pub fn new_dm() -> Self
Sourcepub fn evaluate_commit(&self, commit: &ValidatedCommit) -> bool
pub fn evaluate_commit(&self, commit: &ValidatedCommit) -> bool
The evaluate_commit function is the core function for client side verification
that ValidatedCommit
adheres to the XMTP permission policies set in the PolicySet.
Permissions are checked against the proposer of each action when available, not the committer. This allows one member to commit proposals created by another member, as long as the proposer had permission to create those proposals.
Sourcepub fn from_bytes(bytes: &[u8]) -> Result<Self, PolicyError>
pub fn from_bytes(bytes: &[u8]) -> Result<Self, PolicyError>
Creates a PolicySet from a Vec<u8>.