pub struct MessageIdentifier {
pub cursor: Cursor,
pub group_id: GroupId,
pub created_ns: DateTime<Utc>,
pub previously_processed: bool,
pub internal_id: Option<Vec<u8>>,
pub group_context: Option<GroupContext>,
pub intent_kind: Option<IntentKind>,
}Fields
cursor: Cursorthe cursor of the message as it exists on the network
group_id: GroupIdcreated_ns: DateTime<Utc>previously_processed: booltrue if the message has been processed previously
internal_id: Option<Vec<u8>>the id of the message in the local database
group_context: Option<GroupContext>The context of the MLS Group from this message Indicates that the message is a commit
intent_kind: Option<IntentKind>The kind of intent processed, if this was our own message
Implementations
Sourceimpl MessageIdentifier
impl MessageIdentifier
pub fn builder() -> MessageIdentifierBuilder