pub fn validate_proposal(
proposal: &QueuedProposal,
openmls_group: &MlsGroup,
policy_set: &PolicySet,
immutable_metadata: &GroupMetadata,
mutable_metadata: &GroupMutableMetadata,
) -> Result<(), CommitValidationError>Expand description
Validates a single proposal by checking if the proposer has the required permissions. Returns Ok(()) if the proposal is valid, or an error if validation fails.
This function should be called when receiving proposals to ensure they are valid before they are stored and later committed.