pub enum IdentityStrategy {
CreateIfNotFound {
inbox_id: InboxId,
identifier: Identifier,
nonce: u64,
legacy_signed_private_key: Option<Vec<u8>>,
},
CachedOnly,
}Expand description
The identity strategy determines how the ClientBuilder constructs an identity on startup.
IdentityStrategy::CreateIfNotFound will attempt to create a new identity if one isn’t found in the store.
This is the default behavior.
IdentityStrategy::CachedOnly will attempt to get an identity from the store. If not found, it will
return an error. This is useful if you don’t want to create a new identity on startup because the caller
does not have access to a signer.
IdentityStrategy::ExternalIdentity allows you to provide an already-constructed identity to the
client. This is useful for testing and not expected to be used in production.
Variants
CreateIfNotFound
Tries to get an identity from the disk store. If not found, getting one from backend.
Fields
identifier: IdentifierCachedOnly
Identity that is already in the disk store
Implementations
Sourceimpl IdentityStrategy
impl IdentityStrategy
pub fn inbox_id(&self) -> Option<InboxIdRef<'_>>
Sourcepub fn new(
inbox_id: InboxId,
identifier: Identifier,
nonce: u64,
legacy_signed_private_key: Option<Vec<u8>>,
) -> Self
pub fn new( inbox_id: InboxId, identifier: Identifier, nonce: u64, legacy_signed_private_key: Option<Vec<u8>>, ) -> Self
Create a new Identity Strategy, with IdentityStrategy::CreateIfNotFound.
If an Identity is not found in the local store, creates a new one.