IdentityExt

Trait IdentityExt 

pub trait IdentityExt {
    // Required method
    fn to_unverified(self) -> Result<UnverifiedIdentityUpdate, AssociationError>;
}
Extension trait for Identity types defined in xmtp_id mostly helpful to glue together different parts of the codebase without introducing unnecessary dependencies in other crates

Required Methods

Implementations on Foreign Types

Source

impl IdentityExt for StoredIdentityUpdate

Implementors