load_identity_updates

Function load_identity_updates 

pub async fn load_identity_updates<ApiClient: XmtpApi>(
    api_client: &ApiClientWrapper<ApiClient>,
    conn: &impl DbQuery,
    inbox_ids: &[&str],
) -> Result<HashMap<String, Vec<InboxUpdate>>, ClientError>
For the given list of inbox_ids get all updates from the network that are newer than the last known sequence_id, write them in the db, and return the updates