IdentityUpdates

Struct IdentityUpdates 

pub struct IdentityUpdates<Context> { /* private fields */ }

Implementations

Source

impl<Context> IdentityUpdates<Context>

pub fn new(context: Context) -> Self

Source

impl<'a, Context> IdentityUpdates<Context>
where Context: XmtpSharedContext,

pub async fn batch_get_association_state( &self, conn: &impl DbQuery, identifiers: &[(impl AsIdRef, Option<i64>)], ) -> Result<Vec<AssociationState>, ClientError>

Get the association state for all provided inbox_id/optional sequence_id tuples, using the cache when available If the association state is not available in the cache, this falls back to reconstructing the association state from Identity Updates in the network.

pub async fn get_latest_association_state( &self, conn: &DbConnection<<Context::Db as XmtpDb>::Connection>, inbox_id: InboxIdRef<'a>, ) -> Result<AssociationState, ClientError>

Get the latest association state available on the network for the given inbox_id

pub async fn get_association_state( &self, conn: &impl DbQuery, inbox_id: InboxIdRef<'_>, to_sequence_id: Option<i64>, ) -> Result<AssociationState, ClientError>

Get the association state for a given inbox_id up to the (and inclusive of) the to_sequence_id If no to_sequence_id is provided, use the latest value in the database

pub async fn create_inbox( &self, identifier: Identifier, maybe_nonce: Option<u64>, ) -> Result<SignatureRequest, ClientError>

Generate a CreateInbox signature request for the given wallet address. If no nonce is provided, use 0

pub async fn associate_identity( &self, new_identifier: Identifier, ) -> Result<SignatureRequest, ClientError>

Generate a AssociateWallet signature request using an existing wallet and a new wallet address

pub async fn revoke_identities( &self, identities_to_revoke: Vec<Identifier>, ) -> Result<SignatureRequest, ClientError>

Revoke the given identities from the association state for the client’s inbox

pub async fn revoke_installations( &self, installation_ids: Vec<Vec<u8>>, ) -> Result<SignatureRequest, ClientError>

Revoke the given installations from the association state for the client’s inbox

pub async fn change_recovery_identifier( &self, new_recovery_identifier: Identifier, ) -> Result<SignatureRequest, ClientError>

Generate a ChangeRecoveryAddress signature request using a new identifier

pub async fn apply_signature_request( &self, signature_request: SignatureRequest, ) -> Result<(), ClientError>

Apply a signature request to the client’s inbox by publishing the identity update to the network.

This will error if the signature request is missing signatures, if the signatures are invalid, if the update fails other verifications, or if the update fails to be published to the network.

pub async fn get_installation_diff( &self, conn: &impl DbQuery, group_id: &GroupId, old_group_membership: &GroupMembership, new_group_membership: &GroupMembership, membership_diff: &MembershipDiff<'_>, ) -> Result<InstallationDiff, InstallationDiffError>

Given two group memberships and the diff, get the list of installations that were added or removed between the two membership states.