pub struct GetConfigurationRequest {}Trait Implementations
Sourceimpl Clone for GetConfigurationRequest
impl Clone for GetConfigurationRequest
Sourcefn clone(&self) -> GetConfigurationRequest
fn clone(&self) -> GetConfigurationRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetConfigurationRequest
impl Debug for GetConfigurationRequest
Sourceimpl Default for GetConfigurationRequest
impl Default for GetConfigurationRequest
Sourcefn default() -> GetConfigurationRequest
fn default() -> GetConfigurationRequest
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for GetConfigurationRequest
impl<'de> Deserialize<'de> for GetConfigurationRequest
Sourcefn deserialize<D>(
deserializer: D,
) -> Result<GetConfigurationRequest, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D,
) -> Result<GetConfigurationRequest, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for GetConfigurationRequest
impl Hash for GetConfigurationRequest
Sourceimpl Message for GetConfigurationRequest
impl Message for GetConfigurationRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl Name for GetConfigurationRequest
impl Name for GetConfigurationRequest
Sourceconst NAME: &'static str = "GetConfigurationRequest"
const NAME: &'static str = "GetConfigurationRequest"
Simple name for this
Message.
This name is the same as it appears in the source .proto file, e.g. FooBar.Sourceconst PACKAGE: &'static str = "xmtp.backend.v1"
const PACKAGE: &'static str = "xmtp.backend.v1"
Package name this message type is contained in. They are domain-like
and delimited by
., e.g. google.protobuf.Sourcefn full_name() -> String
fn full_name() -> String
Fully-qualified unique name for this
Message.
It’s prefixed with the package name and names of any parent messages,
e.g. google.rpc.BadRequest.FieldViolation.
By default, this is the package name followed by the message name.
Fully-qualified names must be unique within a domain of Type URLs.Sourceimpl PartialEq for GetConfigurationRequest
impl PartialEq for GetConfigurationRequest
Sourcefn eq(&self, other: &GetConfigurationRequest) -> bool
fn eq(&self, other: &GetConfigurationRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for GetConfigurationRequest
impl Serialize for GetConfigurationRequest
Sourcefn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
fn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Copy for GetConfigurationRequest
impl Eq for GetConfigurationRequest
impl StructuralPartialEq for GetConfigurationRequest