receive_with_welcomes_until

Function receive_with_welcomes_until 

pub async fn receive_with_welcomes_until<C: XmtpSharedContext>(
    context: &C,
    starting_groups: Vec<GroupId>,
    consent_states: Option<Vec<ConsentState>>,
    deadline: Instant,
) -> GroupBarrierRun
Process starting groups and enrolled Welcome discoveries under one deadline. Later local groups and Welcomes above the sampled head cannot extend the run.