pub trait ApiClientIdentity {
// Required method
fn api_client_identity(&self) -> usize;
}Expand description
Stable identity of the Arc that owns a backend API client.
pub trait ApiClientIdentity {
// Required method
fn api_client_identity(&self) -> usize;
}Stable identity of the Arc that owns a backend API client.