pub trait ValidateGroupMembership {
// Required method
async fn check_initial_membership(
&self,
welcome: &WelcomeMembership,
) -> Result<(), GroupError>;
// Provided method
fn check_verified_membership(
&self,
_welcome: &WelcomeMembership,
_db: &impl DbQuery,
) -> Result<(), GroupError> { ... }
}Expand description
Validate public trial membership, then recheck exact proofs under the writer.
Required Methods
Sourceasync fn check_initial_membership(
&self,
welcome: &WelcomeMembership,
) -> Result<(), GroupError>
async fn check_initial_membership( &self, welcome: &WelcomeMembership, ) -> Result<(), GroupError>
Resolve identity proofs and check that the tree matches the membership extension.
Provided Methods
Sourcefn check_verified_membership(
&self,
_welcome: &WelcomeMembership,
_db: &impl DbQuery,
) -> Result<(), GroupError>
fn check_verified_membership( &self, _welcome: &WelcomeMembership, _db: &impl DbQuery, ) -> Result<(), GroupError>
Recheck exact proofs against the database read under the state writer.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.