pub async fn apply_signature_request_with_verifier<ApiClient: XmtpApi>(
api_client: &ApiClientWrapper<ApiClient>,
conn: &impl DbQuery,
signature_request: SignatureRequest,
scw_verifier: &impl SmartContractSignatureVerifier,
) -> Result<(), ClientError>Expand description
Apply a signature request to the client’s inbox by publishing the identity update to the network.
This will error if the signature request is missing signatures, if the signatures are invalid, if the update fails other verifications, or if the update fails to be published to the network.