pub async fn batch_get_association_state_with_verifier(
conn: &impl DbQuery,
identifiers: &[(impl AsIdRef, Option<i64>)],
scw_verifier: &impl SmartContractSignatureVerifier,
) -> Result<Vec<AssociationState>, ClientError>Expand description
Get the association state for all provided inbox_id/optional sequence_id tuples, using the cache when available
If the association state is not available in the cache, this falls back to reconstructing the association state
from Identity Updates in the network.