pub fn calculate_message_id_for_intent(
intent: &StoredGroupIntent,
) -> Result<Option<Vec<u8>>, IntentError>Expand description
Calculate the message id for this intent.
Note
This functions deserializes and decodes a PlaintextEnvelope from encoded bytes.
It would be costly to call this method while pulling extra data from a
PlaintextEnvelope elsewhere. The caller should consider combining implementations.
Returns
Returns Option::None if StoredGroupIntent is not IntentKind::SendMessage or if
an error occurs during decoding of intent data for IntentKind::SendMessage.